@@ -1,26 +1,26 @@
 #!/usr/bin/env python
-#******************************************************************************
-#  $Id: gdal_proximity.py 28882 2015-04-09 15:59:38Z rouault $
-# 
+# ******************************************************************************
+#  $Id$
+#
 #  Name:     gdalproximity
 #  Project:  GDAL Python Interface
 #  Purpose:  Application for computing raster proximity maps.
 #  Author:   Frank Warmerdam, warmerdam@pobox.com
-# 
-#******************************************************************************
+#
+# ******************************************************************************
 #  Copyright (c) 2008, Frank Warmerdam
 #  Copyright (c) 2009-2011, Even Rouault <even dot rouault at mines-paris dot org>
-# 
+#
 #  Permission is hereby granted, free of charge, to any person obtaining a
 #  copy of this software and associated documentation files (the "Software"),
 #  to deal in the Software without restriction, including without limitation
 #  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 #  and/or sell copies of the Software, and to permit persons to whom the
 #  Software is furnished to do so, subject to the following conditions:
-# 
+#
 #  The above copyright notice and this permission notice shall be included
 #  in all copies or substantial portions of the Software.
-# 
+#
 #  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 #  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 #  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -28,18 +28,17 @@
 #  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
-#******************************************************************************
-
-try:
-    from osgeo import gdal
-except ImportError:
-    import gdal
+# ******************************************************************************
 
+import os.path
 import sys
 
+from osgeo import gdal
+
+
 def Usage():
     print("""
-gdal_proximity.py srcfile dstfile [-srcband n] [-dstband n] 
+gdal_proximity.py srcfile dstfile [-srcband n] [-dstband n]
                   [-of format] [-co name=value]*
                   [-ot Byte/Int16/Int32/Float32/etc]
                   [-values n,n,n] [-distunits PIXEL/GEO]
@@ -47,11 +46,61 @@ gdal_proximity.py srcfile dstfile [-srcband n] [-dstband n]
                   [-fixed-buf-val n] [-q] """)
     sys.exit(1)
 
+
+def DoesDriverHandleExtension(drv, ext):
+    exts = drv.GetMetadataItem(gdal.DMD_EXTENSIONS)
+    return exts is not None and exts.lower().find(ext.lower()) >= 0
+
+
+def GetExtension(filename):
+    ext = os.path.splitext(filename)[1]
+    if ext.startswith('.'):
+        ext = ext[1:]
+    return ext
+
+
+def GetOutputDriversFor(filename):
+    drv_list = []
+    ext = GetExtension(filename)
+    for i in range(gdal.GetDriverCount()):
+        drv = gdal.GetDriver(i)
+        if (drv.GetMetadataItem(gdal.DCAP_CREATE) is not None or
+            drv.GetMetadataItem(gdal.DCAP_CREATECOPY) is not None) and \
+           drv.GetMetadataItem(gdal.DCAP_RASTER) is not None:
+            if len(ext) > 0 and DoesDriverHandleExtension(drv, ext):
+                drv_list.append(drv.ShortName)
+            else:
+                prefix = drv.GetMetadataItem(gdal.DMD_CONNECTION_PREFIX)
+                if prefix is not None and filename.lower().startswith(prefix.lower()):
+                    drv_list.append(drv.ShortName)
+
+    # GMT is registered before netCDF for opening reasons, but we want
+    # netCDF to be used by default for output.
+    if ext.lower() == 'nc' and len(drv_list) == 0 and \
+       drv_list[0].upper() == 'GMT' and drv_list[1].upper() == 'NETCDF':
+        drv_list = ['NETCDF', 'GMT']
+
+    return drv_list
+
+
+def GetOutputDriverFor(filename):
+    drv_list = GetOutputDriversFor(filename)
+    if len(drv_list) == 0:
+        ext = GetExtension(filename)
+        if len(ext) == 0:
+            return 'GTiff'
+        else:
+            raise Exception("Cannot guess driver for %s" % filename)
+    elif len(drv_list) > 1:
+        print("Several drivers matching %s extension. Using %s" % (ext, drv_list[0]))
+    return drv_list[0]
+
 # =============================================================================
 #     Mainline
 # =============================================================================
 
-format = 'GTiff'
+
+format = None
 creation_options = []
 options = []
 src_filename = None
@@ -62,16 +111,16 @@ creation_type = 'Float32'
 quiet_flag = 0
 
 gdal.AllRegister()
-argv = gdal.GeneralCmdLineProcessor( sys.argv )
+argv = gdal.GeneralCmdLineProcessor(sys.argv)
 if argv is None:
-    sys.exit( 0 )
+    sys.exit(0)
 
 # Parse command line arguments.
 i = 1
 while i < len(argv):
     arg = argv[i]
 
-    if arg == '-of':
+    if arg == '-of' or arg == '-f':
         i = i + 1
         format = argv[i]
 
@@ -85,27 +134,27 @@ while i < len(argv):
 
     elif arg == '-maxdist':
         i = i + 1
-        options.append( 'MAXDIST=' + argv[i] )
+        options.append('MAXDIST=' + argv[i])
 
     elif arg == '-values':
         i = i + 1
-        options.append( 'VALUES=' + argv[i] )
+        options.append('VALUES=' + argv[i])
 
     elif arg == '-distunits':
         i = i + 1
-        options.append( 'DISTUNITS=' + argv[i] )
+        options.append('DISTUNITS=' + argv[i])
 
     elif arg == '-nodata':
         i = i + 1
-        options.append( 'NODATA=' + argv[i] )
+        options.append('NODATA=' + argv[i])
 
     elif arg == '-use_input_nodata':
         i = i + 1
-        options.append( 'USE_INPUT_NODATA=' + argv[i] )
+        options.append('USE_INPUT_NODATA=' + argv[i])
 
     elif arg == '-fixed-buf-val':
         i = i + 1
-        options.append( 'FIXED_BUF_VAL=' + argv[i] )
+        options.append('FIXED_BUF_VAL=' + argv[i])
 
     elif arg == '-srcband':
         i = i + 1
@@ -131,13 +180,13 @@ while i < len(argv):
 
 if src_filename is None or dst_filename is None:
     Usage()
-    
+
 # =============================================================================
 #    Open source file
 # =============================================================================
 
-src_ds = gdal.Open( src_filename )
-    
+src_ds = gdal.Open(src_filename)
+
 if src_ds is None:
     print('Unable to open %s' % src_filename)
     sys.exit(1)
@@ -149,9 +198,9 @@ srcband = src_ds.GetRasterBand(src_band_n)
 # =============================================================================
 
 try:
-    driver = gdal.IdentifyDriver( dst_filename )
+    driver = gdal.IdentifyDriver(dst_filename)
     if driver is not None:
-        dst_ds = gdal.Open( dst_filename, gdal.GA_Update )
+        dst_ds = gdal.Open(dst_filename, gdal.GA_Update)
         dstband = dst_ds.GetRasterBand(dst_band_n)
     else:
         dst_ds = None
@@ -162,14 +211,17 @@ except:
 #     Create output file.
 # =============================================================================
 if dst_ds is None:
+    if format is None:
+        format = GetOutputDriverFor(dst_filename)
+
     drv = gdal.GetDriverByName(format)
-    dst_ds = drv.Create( dst_filename,
-                         src_ds.RasterXSize, src_ds.RasterYSize, 1,
-                         gdal.GetDataTypeByName(creation_type), creation_options )
+    dst_ds = drv.Create(dst_filename,
+                        src_ds.RasterXSize, src_ds.RasterYSize, 1,
+                        gdal.GetDataTypeByName(creation_type), creation_options)
+
+    dst_ds.SetGeoTransform(src_ds.GetGeoTransform())
+    dst_ds.SetProjection(src_ds.GetProjectionRef())
 
-    dst_ds.SetGeoTransform( src_ds.GetGeoTransform() )
-    dst_ds.SetProjection( src_ds.GetProjectionRef() )
-    
     dstband = dst_ds.GetRasterBand(1)
 
 # =============================================================================
@@ -179,17 +231,12 @@ if dst_ds is None:
 if quiet_flag:
     prog_func = None
 else:
-    prog_func = gdal.TermProgress
-    
-gdal.ComputeProximity( srcband, dstband, options,
-                       callback = prog_func )
-    
+    prog_func = gdal.TermProgress_nocb
+
+gdal.ComputeProximity(srcband, dstband, options,
+                      callback=prog_func)
+
 srcband = None
 dstband = None
 src_ds = None
 dst_ds = None
-
-
-
-
-
